{% load redis_helpers %}
{% if global_stats.total %}
    <table>
        <colgroup>
            <col width="30%"/>
        </colgroup>
        <tbody>
            <tr>
                <th>Status:</th>
                <td>{% widthratio global_stats.online global_stats.total 100 %}% online ({{ global_stats.online|int }} / {{ global_stats.total }})</td>
            </tr>
            <tr>
                <th>Connections:</th>
                <td>{{ global_stats.connected_clients|int|intcomma }}</td>
            </tr>
            <tr>
                <th>Usage:</th>
                <td>{{ global_stats.used_memory|humanize_bytes }}</td>
            </tr>
        </tbody>
    </table>
{% else %}
    <p>No Redis connections were found.</p>
{% endif %}