.server-list {
    margin-left: 0;
    list-style: none;
    text-align: left;
}
.server {
    display: inline-block;
    text-align: left;
    width: 48%;
    margin: 0 5px;
    position: relative;
    margin-bottom: 20px;
    border-radius: 6px;
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
    border-radius: 6px;
    border-top: 1px solid #ddd;
    -webkit-box-shadow: 0 1px 2px rgba(0,0,0,.3);
    -moz-box-shadow: 0 1px 2px rgba(0,0,0,.3);
    box-shadow: 0 1px 2px rgba(0,0,0,.3);
}
.server h3 {
    border-radius: 6px 6px 0 0;
    -moz-border-radius: 6px 6px 0 0;
    -webkit-border-radius: 6px 6px 0 0;
    background: #eee;
    border-bottom: 1px solid #ddd;
    padding: 5px;
    margin-bottom: 5px;
    font-size: 1.3em;
}
.server table {
    margin: 5px;
}
.server .more {
    margin-top: 10px;
    display: none;
}
.server .more caption {
    background: #eee;
}
.server td,
.server th {
    padding: 3px;
    border-bottom: 1px solid #eee;
}
.server th {
    text-align: right;
}
.server tr:last-child td,
.server tr:last-child th {
    border-bottom: 0;
}
.server table {
    border-collapse: collapse;
    margin: 0 0 5px;
}

.server .button {
    position: absolute;
    right: 5px;
    top: 5px;
}